# :coding: utf-8
# :copyright: Copyright (c) 2024 ftrack

try:
    from PySide6 import QtWidgets, QtCore
except ImportError:
    from PySide2 import QtWidgets, QtCore

from ftrack_framework_qt.widgets import BaseWidget
from ftrack_qt.utils.decorators import invoke_in_qt_main_thread


class MayaAbcOptionsSelectorWidget(BaseWidget):
    '''Set a frame range'''

    name = 'maya_abc_options_selector'
    ui_type = 'qt'

    def __init__(
        self,
        event_manager,
        client_id,
        context_id,
        plugin_config,
        group_config,
        on_set_plugin_option,
        on_run_ui_hook,
        parent=None,
    ):
        self._start_le = None
        self._end_le = None

        super(MayaAbcOptionsSelectorWidget, self).__init__(
            event_manager,
            client_id,
            context_id,
            plugin_config,
            group_config,
            on_set_plugin_option,
            on_run_ui_hook,
            parent,
        )

    def pre_build_ui(self):
        layout = QtWidgets.QVBoxLayout()
        layout.setContentsMargins(0, 0, 0, 0)
        layout.setAlignment(QtCore.Qt.AlignTop)
        self.setLayout(layout)
        self.setSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed
        )

    def build_ui(self):
        '''build function widgets.'''

        default_st_frame = 1
        default_end_frame = 10

        if self.plugin_config.get('options'):
            default_st_frame = self.plugin_config['options'].get('start_frame', default_st_frame)
            default_end_frame = self.plugin_config['options'].get('start_frame', default_end_frame)

        st_layout = QtWidgets.QHBoxLayout()
        st_label = QtWidgets.QLabel("Start Frame:")
        self._start_le = QtWidgets.QLineEdit(str(default_st_frame))
        st_layout.addWidget(st_label)
        st_layout.addWidget(self._start_le)

        end_layout = QtWidgets.QHBoxLayout()
        end_label = QtWidgets.QLabel("End Frame:")
        self._end_le = QtWidgets.QLineEdit(str(default_end_frame))
        end_layout.addWidget(end_label)
        end_layout.addWidget(self._end_le)

        self.layout().addLayout(st_layout)
        self.layout().addLayout(end_layout)

    def post_build_ui(self):
        '''hook events'''
        self._start_le.textChanged.connect(self._on_start_frame_changed)
        self._end_le.textChanged.connect(self._on_end_frame_changed)

    def _on_start_frame_changed(self, start_frame):
        '''Updates the start_frame option with the provided *start_frame'''
        if not start_frame:
            return
        self.set_plugin_option('start_frame', float(start_frame))

    def _on_end_frame_changed(self, end_frame):
        '''Updates the end_frame option with the provided *end_frame'''
        if not end_frame:
            return
        self.set_plugin_option('end_frame', float(end_frame))
